@@ -1,12 +1,16 @@
 package MooseX::Storage::Basic;
+{
+  $MooseX::Storage::Basic::VERSION = '0.45';
+}
+BEGIN {
+  $MooseX::Storage::Basic::AUTHORITY = 'cpan:STEVAN';
+}
+# ABSTRACT: The simplest level of serialization
 use Moose::Role;
 
 use MooseX::Storage::Engine;
 use String::RewritePrefix;
 
-our $VERSION   = '0.33';
-our $AUTHORITY = 'cpan:STEVAN';
-
 sub pack {
     my ( $self, %args ) = @_;
     my $e = $self->_storage_get_engine_class(%args)->new( object => $self );
@@ -63,18 +67,28 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
+=for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
+Interactive, Inc. Florian Ragwitz Johannes Plunien Jonathan Rockway Yu Jos
+Boumans Karen Etheridge Ricardo Signes Robert Boone Shawn M Moore Tomas
+Doran Cory Yuval Kogman Watson Dagfinn Ilmari Mannsåker David Golden
+Steinbrunner
+
 =head1 NAME
 
 MooseX::Storage::Basic - The simplest level of serialization
 
+=head1 VERSION
+
+version 0.45
+
 =head1 SYNOPSIS
 
   package Point;
   use Moose;
   use MooseX::Storage;
 
-  our $VERSION = '0.01';
-
   with Storage;
 
   has 'x' => (is => 'rw', isa => 'Int');
@@ -135,19 +149,29 @@ All complex software has bugs lurking in it, and this module is no
 exception. If you find a bug please either email me, or add the bug
 to cpan-RT.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Chris Prather E<lt>chris.prather@iinteractive.comE<gt>
+=over 4
 
-Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
+=item *
+
+Chris Prather <chris.prather@iinteractive.com>
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by Infinity Interactive, Inc.
+This software is copyright (c) 2007 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
