@@ -1,14 +1,16 @@
-
 package MooseX::Storage::Format::JSON;
+{
+  $MooseX::Storage::Format::JSON::VERSION = '0.45';
+}
+BEGIN {
+  $MooseX::Storage::Format::JSON::AUTHORITY = 'cpan:STEVAN';
+}
+# ABSTRACT: A JSON serialization role
 use Moose::Role;
 
 no warnings 'once';
 
 use JSON::Any;
-use utf8 ();
-
-our $VERSION   = '0.33';
-our $AUTHORITY = 'cpan:STEVAN';
 
 requires 'pack';
 requires 'unpack';
@@ -34,10 +36,19 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
+=for :stopwords Chris Prather Stevan Little יובל קוג'מן (Yuval Kogman) Infinity
+Interactive, Inc.
+
 =head1 NAME
 
 MooseX::Storage::Format::JSON - A JSON serialization role
 
+=head1 VERSION
+
+version 0.45
+
 =head1 SYNOPSIS
 
   package Point;
@@ -87,23 +98,29 @@ All complex software has bugs lurking in it, and this module is no
 exception. If you find a bug please either email me, or add the bug
 to cpan-RT.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Chris Prather E<lt>chris.prather@iinteractive.comE<gt>
+=over 4
 
-Stevan Little E<lt>stevan.little@iinteractive.comE<gt>
+=item *
 
-Yuval Kogman E<lt>yuval.kogman@iinteractive.comE<gt>
+Chris Prather <chris.prather@iinteractive.com>
+
+=item *
+
+Stevan Little <stevan.little@iinteractive.com>
+
+=item *
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by Infinity Interactive, Inc.
+This software is copyright (c) 2007 by Infinity Interactive, Inc..
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
